module purge

module load spack/9.4.0

module load cmake/3.22.1
module load boost/1.73.0
module load casacore/3.4.0
module load cfitsio/3.49
module load fftw/3.3.10
module load hdf5/1.10.7
module load openblas/0.3.20
module load openmpi/4.1.3

module load python/3.9.9
module load py-astropy/4.0.1.post1
module load py-casacore/3.4.0
module load py-h5py/3.6.0
module load py-numpy/1.22.3
module load py-pytest/6.2.5
module load py-six/1.16.0

module load dp3/5.4
module load everybeam/0.5.2
module load idg/20220919
